@@ -3,6 +3,7 @@ from typing import List
 from pandas import DataFrame
 from pydantic import Field
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps.base import BaseStep
 from weaverbird.steps.combination import PipelineOrDomainName, resolve_pipeline_for_combination
 from weaverbird.types import DomainRetriever, PipelineExecutor
@@ -27,3 +28,7 @@ class AppendStep(BaseStep):
             for pipeline in self.pipelines
         ]
         return df.append(other_dfs, ignore_index=True)
+
+
+class AppendStepWithVariable(AppendStep, StepWithVariablesMixin):
+    ...
