@@ -1,10 +1,11 @@
-from typing import List
+from typing import List, Union
 
 from pandas import DataFrame
 from pydantic import Field
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps.base import BaseStep
-from weaverbird.types import ColumnName
+from weaverbird.types import ColumnName, TemplatedVariable
 
 _TMP_GROUP_COL_NAME = '__TMP_COL_NAME'
 
@@ -22,7 +23,7 @@ class ArgmaxStep(BaseStep):
             df[_TMP_GROUP_COL_NAME] = 1
             group = [_TMP_GROUP_COL_NAME]
 
-        aggregated_df = df.groupby(group, as_index=False).agg({self.column: 'max'})
+        aggregated_df = df.groupby(group, as_index=False, dropna=False).agg({self.column: 'max'})
 
         if len(self.groups) == 0:
             # we now remove the ugly temp column that we grouped on
@@ -30,3 +31,7 @@ class ArgmaxStep(BaseStep):
             del aggregated_df[_TMP_GROUP_COL_NAME]
 
         return df.merge(aggregated_df, on=[self.column] + self.groups)
+
+
+class ArgmaxStepWithVariable(ArgmaxStep, StepWithVariablesMixin):
+    groups: Union[TemplatedVariable, List[TemplatedVariable]]
