@@ -3,8 +3,9 @@ from typing import List, Literal
 from pandas import DataFrame
 from pydantic import Field
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps import BaseStep
-from weaverbird.types import ColumnName, DomainRetriever, PipelineExecutor
+from weaverbird.types import ColumnName, DomainRetriever, PipelineExecutor, TemplatedVariable
 
 
 class TopStep(BaseStep):
@@ -29,3 +30,8 @@ class TopStep(BaseStep):
             )
         else:
             return getattr(df, pandas_method)(self.limit, self.rank_on)
+
+
+class TopStepWithVariables(TopStep, StepWithVariablesMixin):
+    sort: TemplatedVariable
+    limit: TemplatedVariable
