@@ -1,11 +1,12 @@
-from typing import Callable, List
+from typing import Any, Callable
 
 from pandas import DataFrame
 
 ColumnName = str
-Pipeline = List[dict]
+# Pipeline = List[dict]
 DomainRetriever = Callable[[str], DataFrame]
-PipelineExecutor = Callable[[List[dict]], DataFrame]
+PipelineExecutor = Callable[[Any], DataFrame]
+TemplatedVariable = Any
 
 
 class PopulatedWithFieldnames:
